pub struct GetSchemaResponse {
pub _links: Option<Box<GetSchemaResponseLinks>>,
pub payload: Option<HashMap<String, Value>>,
pub errors: Option<Vec<Error>>,
}Fields
_links: Option<Box<GetSchemaResponseLinks>>payload: Option<HashMap<String, Value>>A JSON schema document describing the expected payload of the action. This object can be validated against http://json-schema.org/draft-04/schema.
errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl GetSchemaResponse
impl GetSchemaResponse
pub fn new() -> GetSchemaResponse